#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-CaYpwBbPofQFOfywOyuqhL
key:                  ghcide-2.3.0.0-CaYpwBbPofQFOfywOyuqhL
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  242bcdfbd45723a1aa264cc8f0876d1e
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-CaYpwBbPofQFOfywOyuqhL
depends:
    Diff-0.5-KXelOT1A7XYBE1m5Mxpw7N Glob-0.10.2-B4dWofglFwp3mtUB4xIvnb
    aeson-2.2.1.0-B3EHpOrhFBKFg56QPA2Q3I array-0.5.6.0
    async-2.2.6-Gml4H6UctygFSqCTsp1iZf base-4.18.2.1
    base16-bytestring-1.0.2.0-31yUxkNIVeJ6WQ1ftMFCcb binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-L8b71mleMbHJVaC8zF8N1a
    co-log-core-0.3.2.6-GuSJsTgYt5FFsUUXhUW401 containers-0.6.7
    cryptohash-sha1-0.11.101.0-Dr7tkgtlkwAD12N9xZyl0y
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-8mX4RaND0tC6RoHj7yTv57
    dependent-sum-0.7.2.0-IR9UOCzrLxCB4QX88EWTTO directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-1rjYhfKUbC5KM6kUJhB1wA exceptions-0.10.7
    extra-1.7.16-COAoMleqge7G93j2zK3Os3 filepath-1.4.300.1
    fingertree-0.1.6.2-8fHbdqLUqga7o5HTrVKraR
    focus-1.0.3.2-1FYHQKjbUjUEMswfNoKyNA ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-GfwB25Bf0SsLneWYOJgo7Q
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-JbZwblUhArrBVg6ZksY9lB
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    hie-bios-0.12.0-eEsgx7XPeoA9QoerKf3NJ
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-Fwuou394YkhHgRNX5gRWe7
    hls-graph-2.3.0.0-EuxF6KpmQWlJOb4Onquj4E
    hls-plugin-api-2.3.0.0-3qB9ychFK6CBBaPUA0tYr4
    implicit-hie-0.1.4.0-85Db6QftnfDBbwwRBhMRf3
    implicit-hie-cradle-0.5.0.1-EmcYqqBr9VF8Pa40KFdGnu
    lens-5.3.4-JL7gOoDjArKFWxi2uC14UJ
    list-t-1.0.5.7-4FMhAfQWKlKD6QQYUqvrCU
    lsp-2.2.0.0-IU5LfR6i0seFHTgeRVBnGx
    lsp-types-2.0.2.0-3KksMNUZDxwI6XHn9FiNQo mtl-2.3.1
    opentelemetry-0.8.0-CtRizRSgGU11iwDJQq9kzG
    optparse-applicative-0.18.1.0-3oCCN3996F8HtRiEC4P5yD
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-890hJtP71KxJCLiD1l5JnX
    prettyprinter-ansi-terminal-1.1.3-G3Jgi8iGiEwJ3EPlBOH51X
    random-1.2.1.3-Gsn6cRa5LQY7Fg5vZFQhOU
    regex-tdfa-1.3.2.5-6zmUIdhGbUZEJaVpWcqCOZ
    row-types-1.0.1.2-2ATmhqoR1BtDNzOLwyU7tD
    safe-exceptions-0.1.7.4-BGySaU8uJj39VCxO5h0Lp3
    sorted-list-0.2.3.1-8C8E8v9lixLLe0zF39SovV
    sqlite-simple-0.4.19.0-4lfN9MLoGcgKpl6bJV4Tf8 stm-2.5.1.0
    stm-containers-1.2.1.1-6E5T9Vb6MPjJNFp9cBsevl
    syb-0.7.3-GhxEKVO9aRZHddME5iK0hL text-2.0.2
    text-rope-0.3-2tUYMQibjWmGZFFzmnf5kt time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-FRGz7PceS9EF7fvbKOBYVe
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

